@@ -22,10 +22,11 @@ from blastMining.script import summary2krona
 from blastMining.script import splitdf2list
 from blastMining.script import create_dir
 from blastMining.script import read_multidfs
+from blastMining.script import get_taxid
 
 def add_arguments(parser):
 
-    parser.add_argument('-v','--version', action='version', version='blastMining v.1.1.0')
+    parser.add_argument('-v','--version', action='version', version='blastMining v.1.2.0')
 
     parser.add_argument("-i", "--input", type=str, required=True, 
         help='''blast.out file. Please use this blast outfmt 6 ONLY:
@@ -40,10 +41,10 @@ def add_arguments(parser):
 (Ignore hits if their evalues are above this threshold)
 [default=1-e3]''')
     
-    parser.add_argument("-pi","--pident", dest="pident",action="store",default=99,type=int,
+    parser.add_argument("-pi","--pident", dest="pident",action="store",default=97,type=int,
         help='''Threshold of p. identity
 (Ignore hits if their p. identities are below this threshold)
-[default=99]''')
+[default=97]''')
     
     parser.add_argument("-n","--topN", dest="topN",action="store",default=10,type=int,
         help="Top N hits used for LCA calculation\n[default=10]")
@@ -108,9 +109,26 @@ def main(args):
     DF3 = pd.concat([DF.reset_index(drop=True), DF2], axis = 1)
     DF3[['Kingdom','Phylum','Class','Order','Family','Genus', 'Species']] = DF3['lineage'].str.split(';', expand=True)
     DF3.drop(['staxid','staxids','lca_x','lca_y','lineage'], axis=1, inplace=True)
-    DF3.to_csv(str('./'+args.outdir+'/'+args.prefix+'.tsv'), header=True, index=None, sep='\t')
+    DF3.to_csv(str('./'+os.path.join(args.outdir, "TMPDIR")+"/temp.df3"), header=True, index=None, sep='\t')
+    get_taxid.get_taxid(DF3, str('./'+os.path.join(args.outdir, "TMPDIR")+"/temp.GETTAXID"))
+
+    run_get_taxid = "cat " + str('./'+os.path.join(args.outdir, "TMPDIR")+"/temp.GETTAXID") + " | cut -f 8 | taxonkit name2taxid -j "+str(args.jobs)+" | awk '!a[$1]++' > "+str('./'+os.path.join(args.outdir, "TMPDIR")+"/temp.TAXID")
+    os.system(run_get_taxid)
+
+    df2 = pd.read_csv(str('./'+os.path.join(args.outdir, "TMPDIR")+"/temp.TAXID"), sep='\t', header= None, dtype=str)
+    df2.columns = ['Species', 'staxid']
+    df2['Species']=df2['Species'].astype(str)
     
-    SD = summary_df.summary_df(DF3, args.sample_name)
+    DF3['Species']=DF3['Species'].astype(str)
+    FD_df = DF3.merge(df2, on="Species")
+
+    FD_df = FD_df[['qseqid', 'staxid', 'Kingdom', 'Phylum', 'Class', 'Order', 'Family', 'Genus', 'Species']]
+
+    df4 = pd.read_csv(str('./'+os.path.join(args.outdir, "TMPDIR")+"/temp.df3"), sep='\t', header=0)
+    df5 = FD_df[["qseqid","staxid"]].merge(df4, on="qseqid", how='left')
+    df5.to_csv(str('./'+args.outdir+'/'+args.prefix+'.tsv'), header=True, index=None, sep='\t')
+    
+    SD = summary_df.summary_df(df5, args.sample_name)
     SD.to_csv(str('./'+args.outdir+'/'+args.prefix+'.summary'), header=True, index=None, sep='\t')
     
     if hasattr(args, 'krona_plot'):
